@@ -1,3 +1,6 @@
+from .time import TimedFunction
+
+@TimedFunction
 def caesar_cipher(text, shift):
     result = ""
     for char in text:
