@@ -1,3 +1,6 @@
+from .time import TimedFunction
+
+@TimedFunction
 def heap_sort(arr):
     n = len(arr)
     for i in range(n // 2 - 1, -1, -1):
