@@ -1,3 +1,6 @@
+from .time import TimedFunction
+
+@TimedFunction
 def insertion_sort(arr):
     n = len(arr)
     for i in range(1, n):
