@@ -1,3 +1,6 @@
+from .time import TimedFunction
+
+@TimedFunction
 def linear_search(arr, target):
     for i in range(len(arr)):
         if arr[i] == target:
