@@ -1,3 +1,6 @@
+from .time import TimedFunction
+
+@TimedFunction
 def merge_sort(arr):
     if len(arr) <= 1:
         return arr
